@@ -3,6 +3,7 @@ init file
 """
 # from .example_class import ExampleClass
 # https://stackoverflow.com/questions/8899198/module-has-no-attribute
+import helpsk.color
 import helpsk.database
 import helpsk.database_base
 import helpsk.date
@@ -11,6 +12,7 @@ import helpsk.pandas
 import helpsk.pandas_style
 import helpsk.plot
 import helpsk.sklearn_eval
+import helpsk.sklearn_search
 import helpsk.sklearn_pipeline
 import helpsk.string
 import helpsk.utility
