@@ -82,6 +82,35 @@ class TestSklearnSearch(unittest.TestCase):
         self.assertIsInstance(categorical.categories[0], OneHotEncoder)
         self.assertIsInstance(categorical.categories[1], CustomOrdinalEncoder)
         del categorical
+        del transformer_search_space
+
+        self.assertRaises(AssertionError,
+                          lambda: ClassifierSearchSpace._build_transformer_search_space(
+                              scaler_min_max=False,
+                              scaler_standard=False,
+                              scaler_none=False,
+                          ))
+        transformer_search_space = ClassifierSearchSpace._build_transformer_search_space(
+            scaler_min_max=True,
+            scaler_standard=False,
+            scaler_none=False,
+        )
+        values = transformer_search_space['prep__numeric__scaler__transformer'].categories
+        self.assertEqual(len(values), 1)
+        self.assertIsInstance(values[0], MinMaxScaler)
+        del values
+        del transformer_search_space
+
+        transformer_search_space = ClassifierSearchSpace._build_transformer_search_space(
+            scaler_min_max=False,
+            scaler_standard=True,
+            scaler_none=False,
+        )
+        values = transformer_search_space['prep__numeric__scaler__transformer'].categories
+        self.assertEqual(len(values), 1)
+        self.assertIsInstance(values[0], StandardScaler)
+        del values
+        del transformer_search_space
 
         transformer_search_space = ClassifierSearchSpace._build_transformer_search_space(
             imputer_strategies=['most_frequent'],
@@ -109,6 +138,7 @@ class TestSklearnSearch(unittest.TestCase):
         self.assertEqual(len(categorical.categories), 1)
         self.assertIsInstance(categorical.categories[0], OneHotEncoder)
         del categorical
+        del transformer_search_space
 
         def to_string(obj):
             return str(obj).\
@@ -171,7 +201,6 @@ class TestSklearnSearch(unittest.TestCase):
         # search space for xgboost with modified params
         xgboost_space = ClassifierSearchSpace._search_space_xgboost(
             eval_metric='logloss',
-            use_label_encoder=False,
             max_depth=(2, 30),
             n_estimators=(10, 10000),
             learning_rate=(0.01111, 0.3333),
@@ -227,19 +256,19 @@ class TestSklearnSearch(unittest.TestCase):
             print_dataframe(results.to_dataframe())
 
         with redirect_stdout_to_file(get_test_path() + '/test_files/sklearn_search/multi-model-search-dataframe__xgboost.txt'):
-            print_dataframe(results.to_dataframe(query="model == 'XGBClassifier(...)'"))
+            print_dataframe(results.to_dataframe(query="model == 'XGBClassifier()'"))
 
         with redirect_stdout_to_file(get_test_path() + '/test_files/sklearn_search/multi-model-search-dataframe__logistic.txt'):
-            print_dataframe(results.to_dataframe(query="model == 'LogisticRegression(...)'"))
+            print_dataframe(results.to_dataframe(query="model == 'LogisticRegression()'"))
 
         with open(get_test_path() + '/test_files/sklearn_search/multi-model-search-dataframe.html', 'w') as file:
             file.write(clean_formatted_dataframe(results.to_formatted_dataframe().render()))
 
         with open(get_test_path() + '/test_files/sklearn_search/multi-model-search-dataframe__xgboost.html', 'w') as file:
-            file.write(clean_formatted_dataframe(results.to_formatted_dataframe(query="model == 'XGBClassifier(...)'").render()))
+            file.write(clean_formatted_dataframe(results.to_formatted_dataframe(query="model == 'XGBClassifier()'").render()))
 
         with open(get_test_path() + '/test_files/sklearn_search/multi-model-search-dataframe__logistic.html', 'w') as file:
-            file.write(clean_formatted_dataframe(results.to_formatted_dataframe(query="model == 'LogisticRegression(...)'").render()))
+            file.write(clean_formatted_dataframe(results.to_formatted_dataframe(query="model == 'LogisticRegression()'").render()))
 
         # pd.set_option('display.max_columns', 500)
         # pd.set_option('display.width', 10000)
@@ -254,14 +283,14 @@ class TestSklearnSearch(unittest.TestCase):
             for x in label_column_formatter(labeled_df['label']):
                 file.write(x)
 
-        labeled_df = results.to_labeled_dataframe(query="model == 'XGBClassifier(...)'")
+        labeled_df = results.to_labeled_dataframe(query="model == 'XGBClassifier()'")
         with redirect_stdout_to_file(get_test_path() + '/test_files/sklearn_search/multi-model-search-labeled_dataframe__xgboost.txt'):
             print_dataframe(labeled_df)
         with open(get_test_path() + '/test_files/sklearn_search/multi-model-search-labeled_dataframe__xgboost__label.txt', 'w') as file:
             for x in label_column_formatter(labeled_df['label']):
                 file.write(x)
 
-        labeled_df = results.to_labeled_dataframe(query="model == 'LogisticRegression(...)'")
+        labeled_df = results.to_labeled_dataframe(query="model == 'LogisticRegression()'")
         with redirect_stdout_to_file(get_test_path() + '/test_files/sklearn_search/multi-model-search-labeled_dataframe__logistic.txt'):
             print_dataframe(labeled_df)
         with open(get_test_path() + '/test_files/sklearn_search/multi-model-search-labeled_dataframe__logistic__label.txt', 'w') as file:
@@ -340,7 +369,9 @@ class TestSklearnSearch(unittest.TestCase):
                                                                                            'label'])])
 
         def remove_parentheses(obj):
-            return re.sub(r'\(.*', '', str(obj).replace('\n', ''))
+            obj = str(obj)
+            obj = obj.replace("OneHotEncoder(handle_unknown='ignore')", "OneHotEncoder()")
+            return re.sub(r'\(.*', '', obj.replace('\n', ''))
 
         self.assertEqual([remove_parentheses(x) for x in bayes_search.cv_results_['param_model'].data],
                          [remove_parentheses(x) for x in cv_dataframe['model']])
@@ -357,7 +388,9 @@ class TestSklearnSearch(unittest.TestCase):
                     assert_np_arrays_are_close(np.array(cv_data),
                                                np.array(hyper_param_df.loc[:, value].tolist()))
                 if key.startswith('prep__'):
-                    self.assertEqual([str(x) for x in cv_data],
+                    self.assertEqual([str(x).replace("OneHotEncoder(handle_unknown='ignore')",
+                                                     "OneHotEncoder()")
+                                      for x in cv_data],
                                      hyper_param_df.loc[:, value].tolist())
 
         self.assertTrue(isinstance(results.test_score_averages, dict))
@@ -415,7 +448,8 @@ class TestSklearnSearch(unittest.TestCase):
                                                bayes_search.best_params_[original_name]))
                 else:
                     self.assertEqual(results.best_params[new_name],
-                                     str(bayes_search.best_params_[original_name]))
+                                     str(bayes_search.best_params_[original_name]).replace("OneHotEncoder(handle_unknown='ignore')",
+                                                                                           "OneHotEncoder()"))
 
     def test_MLExperimentResults_all_models(self):
         search_space = ClassifierSearchSpace(
@@ -427,12 +461,14 @@ class TestSklearnSearch(unittest.TestCase):
             search_spaces=search_space.search_spaces(),  # noqa
             cv=RepeatedKFold(n_splits=3, n_repeats=1, random_state=42),  # 3 fold 1 repeat CV
             scoring='roc_auc',
-            refit=False,  # required if passing in multiple scorers
+            refit=False,  # required if use_label_encoder passing in multiple scorers
             return_train_score=False,
             n_jobs=-1,
             verbose=0,
             random_state=42,
         )
+        # we get convergence warnings with LinearSVC, ignore for now; I do not see this when running with
+        # other datasets
         bayes_search.fit(self.X_train, self.y_train)  # noqa
 
         results = MLExperimentResults.from_sklearn_search_cv(bayes_search,
@@ -458,7 +494,7 @@ class TestSklearnSearch(unittest.TestCase):
                                                                                 return_style=True).render()))
 
         with open(get_test_path() + '/test_files/sklearn_search/multi-model-many-XGBClassifier.html', 'w') as file:
-            file.write(clean_formatted_dataframe(results.to_formatted_dataframe(query='model == "XGBClassifier(...)"').render()))
+            file.write(clean_formatted_dataframe(results.to_formatted_dataframe(query='model == "XGBClassifier()"').render()))
 
         labeled_dataframe = results.to_labeled_dataframe()
         self.assertTrue(all(labeled_dataframe['Trial Index'] == list(range(1, results.number_of_trials + 1))))
@@ -485,13 +521,13 @@ class TestSklearnSearch(unittest.TestCase):
         del labels
 
         _ = results.plot_performance_across_trials(facet_by='model')
-        _ = results.plot_performance_across_trials(query='model == "XGBClassifier(...)"')
-        _ = results.plot_parameter_values_across_trials(query='model == "XGBClassifier(...)"')
-        _ = results.plot_parallel_coordinates(query='model == "XGBClassifier(...)"')
-        _ = results.plot_scatter_matrix(query='model == "XGBClassifier(...)"')
-        _ = results.plot_score_vs_parameter(parameter='max_depth', query='model == "XGBClassifier(...)"')
-        _ = results.plot_parameter_values_across_trials(query='model == "XGBClassifier(...)"')
+        _ = results.plot_performance_across_trials(query='model == "XGBClassifier()"')
+        _ = results.plot_parameter_values_across_trials(query='model == "XGBClassifier()"')
+        _ = results.plot_parallel_coordinates(query='model == "XGBClassifier()"')
+        _ = results.plot_scatter_matrix(query='model == "XGBClassifier()"')
+        _ = results.plot_score_vs_parameter(parameter='max_depth', query='model == "XGBClassifier()"')
+        _ = results.plot_parameter_values_across_trials(query='model == "XGBClassifier()"')
         _ = results.plot_parameter_vs_parameter(parameter_x='max_depth', parameter_y='min_child_weight',
-                                                query='model == "XGBClassifier(...)"')
-        _ = results.plot_performance_non_numeric_params(query='model == "XGBClassifier(...)"')
-        _ = results.plot_performance_numeric_params(query='model == "XGBClassifier(...)"')
+                                                query='model == "XGBClassifier()"')
+        _ = results.plot_performance_non_numeric_params(query='model == "XGBClassifier()"')
+        _ = results.plot_performance_numeric_params(query='model == "XGBClassifier()"')
